#!/bin/sh
export PYSVN_WORKBENCH_STDOUT_LOG=$(tty)
if [ "$PYTHONPATH" = "" ]
then
	export PYTHONPATH=${WORKDIR}/Source
else
	export PYTHONPATH=${WORKDIR}/Source:$PYTHONPATH
fi

export LD_LIBRARY_PATH=${SVNCPP_LIB}
export DYLD_LIBRARY_PATH=${SVNCPP_LIB}
pythonw wb_main.py $*
